@@ -95,7 +95,7 @@ def __create_upstream(upstream_entity, upstream_template, dataset_name, table_na
     upstream_json['Key'] = uuid.uuid1().hex
     upstream_json[UPSTREAM_UPDATED_DATETIME_FIELD_NAME] = default_serializable(update_datetime)
     
-    for key, value in kwargs:
+    for key, value in kwargs.items():
         upstream_json[key] = convert_to_serializable_value(value)
     
     logger.debug('-------------------------------------------------')
